AuthLogIn class

Constructors

AuthLogIn()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

getPrincipal → dynamic
no setter
newAgent ↔ HttpAgent?
getter/setter pair
publicKeyString ↔ String?
getter/setter pair

Static Methods

authenticate(bool isLocal, String middlePageCanisterId, String appHost, String appScheme) → Future<void>
checkLoginStatus(bool isLocal, String backendCanisterId) → Future<bool>
fetchAgent(Map<String, String> queryParams, bool local, String canisterId, Service idLService) → Future<List<Object>>
getActor(String canisterIds, Service idlServices) → CanisterActor
getAllActors(List<String> canisterIds, List<Service> idlServices) → List<CanisterActor>
getDelegations(bool isLocal, String canisterId) → Future<List<Object>>
manualLogin(Uri uri, bool isLocal, String backendCanisterId, Service idlService) → Future<List<Object?>>